@@ -73,6 +73,7 @@ GdkPixbuf *pld;
 GdkPixbuf *openna;
 GdkPixbuf *fedora;
 GdkPixbuf *conectiva;
+GdkPixbuf *black_panther;
 
 enum {
 	BOGUS,
@@ -90,7 +91,7 @@ enum {
 	PLATFORM_LIST_COL_LAST
 };
 
-static GtkObjectClass *parent_class;
+static GObjectClass *parent_class;
 static gint gsttool_signals [LAST_SIGNAL] = { 0 };
 
 static void     gst_tool_idle_run_directives_remove (GstTool *tool);
@@ -435,6 +436,7 @@ gst_tool_create_distro_images (void)
 	openna = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/openna.png", NULL);
 	fedora = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/fedora.png", NULL);
 	conectiva = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/conectiva.png", NULL);
+	black_panther = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/black_panther.png", NULL);
 }
 
 static void
@@ -588,8 +590,8 @@ gst_tool_kill_tool_cb (GstDirectiveEntry *entry)
 	GstTool *tool = entry->tool;
 
 	gst_tool_kill_backend_cb (entry);
-	
-	g_signal_emit_by_name (G_OBJECT (tool), "destroy");
+
+	g_object_unref (G_OBJECT (tool));
 }
 
 /* kills the whole tool */
@@ -899,10 +901,9 @@ gst_tool_load (GstTool *tool)
 #endif	
 	}
 
+	if (tool->config)
+		g_signal_emit (G_OBJECT (tool), gsttool_signals[FILL_GUI], 0);
 
-	if (tool->config){
-		g_signal_emit (GTK_OBJECT (tool), gsttool_signals[FILL_GUI], 0);
-	}
 	return tool->config != NULL;
 }
 
@@ -922,7 +923,7 @@ gst_tool_save (GstTool *tool, gboolean restore)
 
 	gst_dialog_freeze_visible (tool->main_dialog);
 
-	g_signal_emit (GTK_OBJECT (tool), gsttool_signals[FILL_XML], 0);
+	g_signal_emit (G_OBJECT (tool), gsttool_signals[FILL_XML], 0);
 #ifdef GST_DEBUG
 	/* don't actually save if we are just pretending */
 	if (tool->root_access == ROOT_ACCESS_SIMULATED) {
@@ -985,12 +986,6 @@ gst_tool_save_cb (GtkWidget *w, GstTool *tool)
 	gst_tool_save (tool, FALSE);
 }
 
-void
-gst_tool_restore_cb (GtkWidget *w, GstTool *tool)
-{
-	gst_tool_save (tool, TRUE);
-}
-
 void
 gst_tool_load_try (GstTool *tool)
 {
@@ -1051,28 +1046,23 @@ gst_tool_main_with_hidden_dialog (GstTool *tool, gboolean no_main_loop)
 }
 
 static void
-gst_tool_destroy (GtkObject *object)
+gst_tool_finalize (GObject *object)
 {
-	GstTool *tool;
-
-	tool = GST_TOOL (object);
-	
-	parent_class->destroy (object);
+	parent_class->finalize (object);
 	gtk_main_quit ();
 }
 
 static void
-gst_tool_class_init (GstToolClass *klass)
+gst_tool_class_init (GstToolClass *class)
 {	
-	GtkObjectClass *object_class;
+	GObjectClass *gobject_class;
 
-	object_class = (GtkObjectClass *)klass;
-
-	parent_class = g_type_class_peek_parent (klass);
+	gobject_class = G_OBJECT_CLASS (class);
+	parent_class = g_type_class_peek_parent (class);
 
 	gsttool_signals[FILL_GUI] = 
 		g_signal_new ("fill_gui",
-			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_OBJECT_CLASS_TYPE (gobject_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GstToolClass, fill_gui),
 			      NULL, NULL,
@@ -1080,7 +1070,7 @@ gst_tool_class_init (GstToolClass *klass)
 			      G_TYPE_NONE, 0);
 	gsttool_signals[FILL_XML] = 
 		g_signal_new ("fill_xml",
-			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_OBJECT_CLASS_TYPE (gobject_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GstToolClass, fill_xml),
 			      NULL, NULL,
@@ -1088,14 +1078,14 @@ gst_tool_class_init (GstToolClass *klass)
 			      G_TYPE_NONE, 0);
 	gsttool_signals[CLOSE] = 
 		g_signal_new ("close",
-			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_OBJECT_CLASS_TYPE (gobject_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GstToolClass, close),
 			      NULL, NULL,
 			      gst_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 
-	object_class->destroy = gst_tool_destroy;
+	gobject_class->finalize = gst_tool_finalize;
 }
 
 static void
@@ -1226,8 +1216,8 @@ gst_tool_type_init (GstTool *tool)
 	tool->report_gui = xml  = gst_tool_load_glade_common (tool, "report_window");
 
 	tool->report_window     = glade_xml_get_widget (xml, "report_window");
-	g_signal_connect (GTK_OBJECT (tool->report_window), "delete_event",
-			    G_CALLBACK (report_window_close_cb), tool);
+	g_signal_connect (G_OBJECT (tool->report_window), "delete_event",
+			  G_CALLBACK (report_window_close_cb), tool);
 
 	tool->report_label      = glade_xml_get_widget (xml, "report_label");
 
@@ -1262,7 +1252,7 @@ gst_tool_get_type (void)
 			(GInstanceInitFunc) gst_tool_type_init
 		};
 		
-		gsttool_type = g_type_register_static (GTK_TYPE_OBJECT, "GstTool", &gsttool_info, 0);
+		gsttool_type = g_type_register_static (G_TYPE_OBJECT, "GstTool", &gsttool_info, 0);
 	}
 
 	return gsttool_type;
@@ -1313,10 +1303,6 @@ gst_tool_construct (GstTool *tool, const char *name, const char *title)
 			  "apply",
 			  G_CALLBACK (gst_tool_save_cb),
 			  tool);
-	g_signal_connect (G_OBJECT (tool->main_dialog),
-			  "restore",
-			  G_CALLBACK (gst_tool_restore_cb),
-			  tool);
 
 	tool->report_hook_list = NULL;
 	memset (&tool->report_hook_defaults, 0, sizeof (GstReportHook *) * GST_MAJOR_MAX);
@@ -1376,8 +1362,7 @@ gst_tool_set_close_func (GstTool *tool, GstCloseFunc close_cb, gpointer data)
 	g_return_if_fail (GST_IS_TOOL (tool));
 
 	if (close_cb)
-		g_signal_connect (GTK_OBJECT (tool), "close", G_CALLBACK (close_cb), data);
-
+		g_signal_connect (G_OBJECT (tool), "close", G_CALLBACK (close_cb), data);
 }
 
 void
@@ -1600,10 +1585,11 @@ gst_init (const gchar *app_name, int argc, char *argv [], const poptOption optio
  	program = gnome_program_init (app_name, VERSION,
 				      LIBGNOMEUI_MODULE, argc, argv,
 				      GNOME_PARAM_POPT_TABLE, options,
+				      GNOME_PARAM_APP_DATADIR, DATADIR,
 				      GNOME_PARAM_HUMAN_READABLE_NAME,
 				      _("GNOME System Tools"),
 				      NULL);
-	try_show_usage_warning ();
+	/* try_show_usage_warning (); */
 }
 
 static gboolean
@@ -1740,10 +1726,37 @@ gst_tool_write_to_backend (GstTool *tool, gchar *string)
 		if (nread % REDRAW_NCHARS == 0)
 			while (gtk_events_pending ())
 				gtk_main_iteration ();
-
 	} while (nread < strlen (string));
 
 	while (fflush (tool->backend_stream) != 0);
 
 	fcntl (tool->backend_master_fd, F_SETFL, O_NONBLOCK);
 }
+
+void
+gst_tool_show_help (GstTool *tool, gchar *section)
+{
+	GError    *error = NULL;
+	gchar     *help_file;
+
+	help_file = g_strdup_printf ("%s-admin", tool->name);
+	gnome_help_display (help_file, section, &error);
+
+	if (error) {
+		GtkWidget *dialog;
+
+		dialog = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+					     GTK_DIALOG_MODAL,
+					     GTK_MESSAGE_ERROR,
+					     _("Could not display help"),
+					     error->message,
+					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					     NULL);
+
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+		g_error_free (error);
+	}
+
+	g_free (help_file);
+}
